@@ -1,5 +1,8 @@
 package Dancer2::Plugin::FormValidator::Role::HasMessages;
 
+use strict;
+use warnings;
+
 use Moo::Role;
 
 requires 'messages';
